package billing

import (
	"crypto/hmac"
	"crypto/sha256"
	"testing"
)

func TestSignature(t *testing.T) {
	digestMaker := hmac.New(sha256.New, []byte("SECRET"))

	bs := &billingSample{
		CounterName:   "storage.account.objects.size",
		CounterType:   "gauge",
		CounterUnit:   "B",
		CounterVolume: 621163549213,
		MessageID:     "31c5a628-f427-11ea-8643-001e67ecb5aa",
		ProjectID:     "ec4c8a43984f43cbadc5bda1118b1ee2",
		ResourceID:    "ec4c8a43984f43cbadc5bda1118b1ee2",
		ResourceMetadata: &resourceMetadata{
			InfraName: "9914",
			InfraType: "ovhcloud",
			PolicyStat: []*policyStat{
				{
					BytesUsed:          1996005601,
					ContainerCount:     1,
					ObjectCount:        4,
					StoragePolicyIndex: 0,
					StoragePolicyName:  "PCS",
				},
				{
					BytesUsed:          619167543612,
					ContainerCount:     10,
					ObjectCount:        14184,
					StoragePolicyIndex: 1,
					StoragePolicyName:  "PCA",
				},
			},
			RegionName: "GRA",
		},
		Source:    "GRA",
		Timestamp: "2020-09-11T12:06:16Z",
	}

	bs.sign(digestMaker)

	expectedSignature := "9864ed97cef78a8c682336b7a9c351030061ff096c4bc583931e9d7ea18a0331"
	if bs.MessageSignature != expectedSignature {
		t.Fatalf(`Wrong message signature, expected: "%s", got "%s"`, expectedSignature, bs.MessageSignature)
	}
}
